@@ -1,7 +1,7 @@
 package App::cpm::Tutorial;
 use strict;
 use warnings;
-our $VERSION = '0.305';
+our $VERSION = '0.306';
 1;
 __END__
 
@@ -20,17 +20,15 @@ which is fast!
 
 =head2 How to install cpm
 
-If you have L<cpanm>, then
+From CPAN:
 
   $ cpanm -nq App::cpm
 
-If not, then
-
-  $ curl -sL http://cpanmin.us | perl - -nq App::cpm
-
-Moreover if you use perl 5.10.1+, then you can fetch I<self-contained> cpm.
+Or, download a I<self-contained> cpm:
 
   $ curl -sL https://git.io/cpm > cpm
+  $ chmod +x cpm
+  $ ./cpm --version
 
   # you can even install modules without installing cpm
   $ curl -sL https://git.io/cpm | perl - install Plack
